### 0.10.2 {small}`2024-04-15`

```{rubric} Features
```
* adds the option to return the results for `get.aggregate` as sparse matrices if the input is sparse {pr}`160` {smaller}`S Dicks`
* adds support for `rapids-24.04` {pr}`166` {smaller}`S Dicks`


```{rubric} Performance
```

* for `pp.scale` replaces array operation with an elementwise kernel to improve memory footprint {pr}`159` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* fixes small bugs with pandas in `ligrec` {pr}`166` {smaller}`S Dicks`


```{rubric} Misc
```
* moves the notebooks from docs into a submodule {pr}`164` {smaller}`S Dicks`
* moves tests to rapids-24.04 {pr}`166` {smaller}`S Dicks`
* unpinned pandas version {pr}`166` {smaller}`S Dicks`
